Reading and writing
===================

.. automodule:: elli.importer.nexus
    :members:

.. automodule:: elli.importer.spectraray
    :members:

.. automodule:: elli.importer.woollam
    :members:
